package ezc.tests;

import static org.junit.Assert.*;

import java.util.GregorianCalendar;

import org.junit.Test;

import ezc.model.Annuncio;
import ezc.model.Filtro;
import ezc.model.TipoAnnuncio;
import ezc.model.TipologiaImmobile;

public class FiltroTests
{	
	private Annuncio getAnnuncio1()
	{
		GregorianCalendar gc = new GregorianCalendar();
		gc.add(GregorianCalendar.DAY_OF_YEAR, -2);
		return new Annuncio("V123", TipologiaImmobile.MONOLOCALE, 110, "Descrizione", "Ravenna", "Stadio", 220, true, true, gc.getTime());
	}
	
	@Test
	public void testFiltraTipoAnnuncioA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, -1, false, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraTipoAnnuncioB()
	{
		Filtro f = new Filtro(TipoAnnuncio.AFFITTO, null, null, null, -1, false, false, 5);
		assertFalse(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraTipologiaImmobileA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, TipologiaImmobile.MONOLOCALE, null, null, -1, false, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraTipologiaImmobileB()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, TipologiaImmobile.BILOCALE, null, null, -1, false, false, 5);
		assertFalse(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraCittaA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, "Ravenna", null, -1, false, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraCittaB()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, "Bologna", null, -1, false, false, 5);
		assertFalse(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraZonaA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, "Stadio", -1, false, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraZonaB()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, "Porto", -1, false, false, 5);
		assertFalse(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraMaxA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, 300, false, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraMaxB()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, 100, false, false, 5);
		assertFalse(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraAscA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, -1, true, false, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraPostoAutoA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, -1, false, true, 5);
		assertTrue(f.filtra(getAnnuncio1()));
	}
	
	@Test
	public void testFiltraPeriodoA()
	{
		Filtro f = new Filtro(TipoAnnuncio.VENDITA, null, null, null, -1, false, true, 1);
		assertFalse(f.filtra(getAnnuncio1()));
	}

}

