package ezc.ui;

import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collection;

import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

import ezc.model.Filtro;
import ezc.model.TipoAnnuncio;
import ezc.model.TipologiaImmobile;

public class FiltroPanel extends JPanel implements ActionListener
{
	private static final long serialVersionUID = 1L;
	
	private JComboBox tipoCombo;
	
	private JComboBox tipologiaCombo;

	private Controller controller;

	private JComboBox cittaCombo;

	private JComboBox zonaCombo;

	private JCheckBox tipologiaCheckBox;

	private JCheckBox cittaCheckBox;

	private JCheckBox zonaCheckBox;

	private JTextField maxRichiestaTextField;

	private JCheckBox ascensoreCheckBox;

	private JCheckBox postoAutoCheckBox;

	private JCheckBox periodoCheckBox;

	private JTextField periodoTextField;

	private JCheckBox maxRichiestaCheckBox;

	public FiltroPanel(Controller controller)
	{
		this.controller = controller;
		initGui();
	}

	public Filtro getFiltro()
	{
		int maxRichiesta = -1;
		int periodo = -1;
		
		if (maxRichiestaCheckBox.isSelected())
		{
			try
			{
				maxRichiesta = Integer.parseInt(maxRichiestaTextField.getText());
			}
			catch (NumberFormatException e)
			{
				JOptionPane.showMessageDialog(this, "Formato campo 'Max Richiesta' errato - filtro disabilitato");
				maxRichiestaCheckBox.setSelected(false);
			}
		}
		if (periodoCheckBox.isSelected())
		{
			try
			{
				Integer.parseInt(periodoTextField.getText());
			}
			catch (NumberFormatException e)
			{
				JOptionPane.showMessageDialog(this, "Formato campo 'Periodo' errato - filtro disabilitato");
				periodoCheckBox.setSelected(false);
			}
		}
		return new Filtro(
				TipoAnnuncio.AFFITTO == tipoCombo.getSelectedItem() ? TipoAnnuncio.AFFITTO : TipoAnnuncio.VENDITA,
				tipologiaCheckBox.isSelected() ? (TipologiaImmobile)tipologiaCombo.getSelectedItem() : null,
				cittaCheckBox.isSelected() ? (String)cittaCombo.getSelectedItem() : null,
				zonaCheckBox.isSelected() ? (String)zonaCombo.getSelectedItem() : null,
				maxRichiesta,
				ascensoreCheckBox.isSelected(),
				postoAutoCheckBox.isSelected(),
				periodo
				);
	}
	
	private void initGui()
	{
		setLayout(new GridLayout(8, 1));
		
		JPanel tipoPanel = new JPanel();
		{
			tipoPanel.setLayout(new FlowLayout());
			tipoPanel.add(new JLabel("Tipo Annuncio:"));
			tipoCombo = new JComboBox(TipoAnnuncio.values());
			tipoPanel.add(tipoCombo);
		}
		add(tipoPanel);
		
		JPanel tipologiaPanel = new JPanel();
		{
			tipologiaPanel.setLayout(new FlowLayout());			
			tipologiaCheckBox = new JCheckBox();
			tipologiaPanel.add(tipologiaCheckBox);
			tipologiaPanel.add(new JLabel("Tipologia Immobile:"));
			tipologiaCombo = new JComboBox(TipologiaImmobile.values());
			tipologiaPanel.add(tipologiaCombo);
		}
		add(tipologiaPanel);
		
		JPanel cittaPanel = new JPanel();
		{
			cittaPanel.setLayout(new FlowLayout());	
			cittaCheckBox = new JCheckBox();
			cittaPanel.add(cittaCheckBox);
			cittaPanel.add(new JLabel("Citt:"));
			cittaCombo = new JComboBox(controller.getElencoCitta().toArray(new String[0]));
			cittaCombo.addActionListener(this);
			cittaPanel.add(cittaCombo);
		}
		add(cittaPanel);
		
		JPanel zonaPanel = new JPanel();
		{
			zonaPanel.setLayout(new FlowLayout());
			zonaCheckBox = new JCheckBox();
			zonaPanel.add(zonaCheckBox);
			zonaPanel.add(new JLabel("Zona:"));
			zonaCombo = new JComboBox();
			zonaPanel.add(zonaCombo);
			bindZonaCombo();
		}
		add(zonaPanel);
		
		JPanel maxRichiestaPanel = new JPanel();
		{
			maxRichiestaPanel.setLayout(new FlowLayout());
			maxRichiestaCheckBox = new JCheckBox();
			maxRichiestaPanel.add(maxRichiestaCheckBox);
			maxRichiestaPanel.add(new JLabel("Max Richiesta:"));
			maxRichiestaTextField = new JTextField(10);
			maxRichiestaPanel.add(maxRichiestaTextField);
		}
		add(maxRichiestaPanel);
		
		JPanel ascensorePanel = new JPanel();
		{
			ascensorePanel.setLayout(new FlowLayout());
			ascensoreCheckBox = new JCheckBox("Con Ascensore");
			ascensorePanel.add(ascensoreCheckBox);
		}
		add(ascensorePanel);
		
		JPanel postoAutoPanel = new JPanel();
		{
			postoAutoPanel.setLayout(new FlowLayout());
			postoAutoCheckBox = new JCheckBox("Con Posto Auto");
			postoAutoPanel.add(postoAutoCheckBox);
		}
		add(postoAutoPanel);
		
		JPanel periodoPanel = new JPanel();
		{
			periodoPanel.setLayout(new FlowLayout());
			periodoCheckBox = new JCheckBox();
			periodoPanel.add(periodoCheckBox);
			periodoPanel.add(new JLabel("Periodo (gg):"));
			periodoTextField = new JTextField(10);
			periodoPanel.add(periodoTextField);
		}
		add(periodoPanel);
	}

	private void bindZonaCombo()
	{
		String citta = (String)cittaCombo.getSelectedItem();
		if (citta != null)
		{
			zonaCombo.removeAllItems();
			Collection<String> zone = controller.getElencoZone(citta);
			for (String zona : zone)
			{
				zonaCombo.addItem(zona);
			}
		}		
	}

	@Override
	public void actionPerformed(ActionEvent e)
	{
		if (e.getSource() == cittaCombo)
		{
			bindZonaCombo();
		}
	}
}
