package ezc.ui;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.DateFormat;
import java.util.Collection;
import java.util.Locale;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import ezc.model.Annuncio;
import ezc.model.Filtro;

public class MainFrame extends JFrame implements ActionListener
{
	private static final long serialVersionUID = 1L;
	
	private Controller controller;
	private FiltroPanel filtroPanel;
	private JButton searchButton;
	private JTextArea resultsTextArea;
	
	private DateFormat dateFormat;

	public MainFrame(Controller controller)
	{
		this.controller = controller;
		this.dateFormat = DateFormat.getDateInstance(DateFormat.SHORT, Locale.ITALY);

		initGui();
	}

	private void initGui()
	{
		setLayout(new BorderLayout());

		JPanel lineStartPanel = new JPanel();
		{
			lineStartPanel.setLayout(new BoxLayout(lineStartPanel, BoxLayout.PAGE_AXIS));
			filtroPanel = new FiltroPanel(controller);
			lineStartPanel.add(filtroPanel);
			
			searchButton = new JButton("Cerca");
			searchButton.addActionListener(this);
			lineStartPanel.add(searchButton);
		}
		getContentPane().add(lineStartPanel, BorderLayout.LINE_START);
		
		resultsTextArea = new JTextArea(20, 80);
		resultsTextArea.setEditable(false);
		JScrollPane scrollPane = new JScrollPane(resultsTextArea);
		getContentPane().add(scrollPane);
		
		pack();
	}

	@Override
	public void actionPerformed(ActionEvent e)
	{
		Filtro filtro = filtroPanel.getFiltro();
		Collection<Annuncio> annunci = controller.ricerca(filtro);
		mostraAnnunci(annunci);
	}

	private void mostraAnnunci(Collection<Annuncio> annunci)
	{
		StringBuilder sb = new StringBuilder();
		for (Annuncio annuncio : annunci)
		{
			sb.append("Codice: ");
			sb.append(annuncio.getCodice());
			sb.append("\n");
			
			sb.append("Tipologia: ");
			sb.append(annuncio.getTipologia());
			sb.append("\n");
			
			sb.append("Metri Quadri: ");
			sb.append(annuncio.getMq());
			sb.append("\n");
			
			sb.append("Descrizione: ");
			sb.append(annuncio.getDescrizione());
			sb.append("\n");
			
			sb.append("Citt: ");
			sb.append(annuncio.getCitta());
			sb.append("\n");
			
			sb.append("Zona: ");
			sb.append(annuncio.getZona());
			sb.append("\n");
						
			sb.append("Ascensore: ");
			sb.append(annuncio.hasAscensore() ? "S" : "No");
			sb.append("\n");
						
			sb.append("Posto Auto: ");
			sb.append(annuncio.hasPostoAuto() ? "S" : "No");
			sb.append("\n");
			
			sb.append("Data Pubblicazione: ");
			sb.append(dateFormat.format(annuncio.getPubblicazione()));
			sb.append("\n");
			
			sb.append("Richiesta: ");
			sb.append(annuncio.getRichiesta());
			sb.append("\n\n");
		}
		resultsTextArea.setText(sb.toString());
	}
}
